profiling

package
v0.2.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: May 30, 2026 License: AGPL-3.0 Imports: 6 Imported by: 0

Documentation

Overview

Package profiling provides one-shot pprof dump commands for runtime diagnosis of goroutine, heap, and CPU performance.

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func DumpAllCmd added in v0.2.0

func DumpAllCmd(d time.Duration) tea.Cmd

DumpAllCmd returns a Cmd that collects a CPU profile for the given duration (if > 0), then writes goroutine and heap profiles to timestamped .pb.gz files in the current directory.

Types

type ProfilesDumped

type ProfilesDumped struct {
	CPUProfilePath string
	GoroutinePath  string
	HeapPath       string
	Err            error
}

ProfilesDumped is delivered by DumpAllCmd with the paths of written profile files.

Jump to